
from odoo.fields import Command
from odoo.tests import tagged
from odoo.addons.base.tests.common import HttpCaseWithUserPortal
from odoo.addons.saas_worker.tests.util import countries
from odoo.addons.website.tools import MockRequest


@tagged('post_install', '-at_install')
class TestShop(HttpCaseWithUserPortal):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        user = cls.user_portal
        website = cls.env.ref('website.default_website').with_user(user.id)

        cls.product_id = cls.env['product.product'].create({
            'name': "Product",
            'is_published': True,
            'list_price': 245.0,
        })

        cls.quotmpl_yearly = cls.env["sale.order.template"].create({
            'name': 'Yearly',
            'plan_id': cls.env.ref('openerp_enterprise.subscription_plan_odoo_yearly_plan').id,
            'sale_order_template_line_ids': [
                Command.create({'product_id': cls.product_id.id, 'product_uom_qty': 1.0}),
            ]
        })

        with MockRequest(cls.env, website=website):
            cls.cart = website.sale_get_order(force_create=True)

    @countries('IN')
    def test_01_check_payment_providers_ogone_india_message(self):
        """
        Ensure that a custom message is displayed for Indian clients using Ogone
        """
        pay_provider = self.env.ref('openerp_enterprise.payment_acquirer_ogone')
        pay_provider.state = 'test'
        pay_provider.is_published = True
        pay_provider.allow_express_checkout = True

        self.cart._cart_update(product_id=self.product_id.id, add_qty=1)
        self.start_tour("/shop/cart", 'check_payment_providers_ogone_india_message', login='portal')

    def test_02_check_payment_providers_hide_auto_tokenize_msg_for_yearly_sub(self):
        """
        Ensure that for yearly subscriptions, the tokenization is optional even if the payment method allows for tokenization
        """
        pay_provider = self.env.ref('openerp_enterprise.payment_acquirer_ogone')
        pay_provider.state = 'test'
        pay_provider.is_published = True
        pay_provider.allow_express_checkout = True

        self.product_id.write({
            'recurring_invoice': True,
            'product_subscription_pricing_ids': [Command.create({
                'plan_id': self.env.ref('openerp_enterprise.subscription_plan_odoo_yearly_plan'),
                'price': 100,
            })],
        })
        self.cart._cart_update(product_id=self.product_id.id, add_qty=1)
        self.start_tour("/shop/cart", 'check_payment_providers_hide_auto_tokenize_msg_for_yearly_sub', login='portal')
